@@ -80,7 +80,8 @@ parameter_field_schema["parameters"] = {
 }
 parameter_field_schema["type"]["allowed"].append("nested")
 parameter_field_schema["type"]["oneof"].insert(
-    0, {"allowed": ["nested"], "dependencies": "parameters"},
+    0,
+    {"allowed": ["nested"], "dependencies": "parameters"},
 )
 
 parameter_group_schema = {
